@@ -7,14 +7,15 @@ const cloneForeignSchemaSQL = `CREATE OR REPLACE FUNCTION clone_foreign_schema(
     RETURNS text AS
 $BODY$
 
-DECLARE
+DECLARE	
     src_oid          oid;
     object           text;
     dest_table       text;
-    table_sql      text;
+    table_sql        text;
     columns_sql      text;
     type_            text;
     column_          text;
+    underlying_type  text;
     res              text;
 BEGIN
 
@@ -28,48 +29,51 @@ BEGIN
         RETURN '';
     END IF;
 
--- Create schema
+    -- Create schema
     EXECUTE 'DROP SCHEMA IF EXISTS "' ||  dest_schema || '" CASCADE';
     EXECUTE 'CREATE SCHEMA "' || dest_schema || '"';
     EXECUTE 'GRANT USAGE ON SCHEMA "' || dest_schema || '" TO steampipe_users';
     EXECUTE 'ALTER DEFAULT PRIVILEGES IN SCHEMA "' || dest_schema || '" GRANT SELECT ON TABLES TO steampipe_users';
 
--- Create tables
+    -- Create tables
     FOR object IN
         SELECT TABLE_NAME::text
         FROM information_schema.tables
         WHERE table_schema = source_schema
           AND table_type = 'FOREIGN'
+    LOOP
+        columns_sql := '';
 
+        FOR column_, type_ IN
+            SELECT c.column_name::text, 
+                   CASE 
+                       WHEN c.data_type = 'USER-DEFINED' THEN t.typname
+                       ELSE c.data_type
+                   END as data_type
+            FROM information_schema.COLUMNS c
+            LEFT JOIN pg_catalog.pg_type t ON c.udt_name = t.typname
+            WHERE c.table_schema = source_schema
+              AND c.TABLE_NAME = object
         LOOP
-            columns_sql := '';
-
-            FOR column_, type_ IN
-                SELECT column_name::text, data_type::text
-                FROM information_schema.COLUMNS
-                WHERE table_schema = source_schema
-                  AND TABLE_NAME = object
-
-                LOOP
-                    IF columns_sql <> ''
-                    THEN
-                        columns_sql = columns_sql || ',';
-                    END IF;
-                    columns_sql = columns_sql || quote_ident(column_) || ' ' || type_;
-                END LOOP;
-
-            dest_table := '"' || dest_schema || '".' || quote_ident(object);
-            table_sql :='CREATE FOREIGN TABLE ' || dest_table || ' (' || columns_sql || ') SERVER steampipe OPTIONS (table '|| $$'$$ || quote_ident(object) || $$'$$ || ') ';
-            EXECUTE table_sql;
-
-            SELECT CONCAT(res, table_sql, ';') into res;
+            IF columns_sql <> ''
+            THEN
+                columns_sql = columns_sql || ',';
+            END IF;
+            columns_sql = columns_sql || quote_ident(column_) || ' ' || type_;
         END LOOP;
+
+        dest_table := '"' || dest_schema || '".' || quote_ident(object);
+        table_sql :='CREATE FOREIGN TABLE ' || dest_table || ' (' || columns_sql || ') SERVER steampipe OPTIONS (table '|| $$'$$ || quote_ident(object) || $$'$$ || ') ';
+        EXECUTE table_sql;
+
+        SELECT CONCAT(res, table_sql, ';') into res;
+    END LOOP;
     RETURN res;
 END
 
 $BODY$
-    LANGUAGE plpgsql VOLATILE
-                     COST 100;
+LANGUAGE plpgsql VOLATILE
+                 COST 100;
 `
 
 const cloneCommentsSQL = `
