@@ -154,13 +154,13 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, pluginMa
 			// we need to refetch the rate limiters for this plugin
 			if res.pluginBinaryChanged {
 				// store map item of plugin name to connection name (so we only have one entry per plugin)
-				pluginShortName := GlobalConfig.Connections[requiredConnectionState.ConnectionName].PluginAlias
-				updates.PluginsWithUpdatedBinary[pluginShortName] = requiredConnectionState.ConnectionName
+				pluginLogName := GlobalConfig.Connections[requiredConnectionState.ConnectionName].Plugin
+				updates.PluginsWithUpdatedBinary[pluginLogName] = requiredConnectionState.ConnectionName
 			}
 		}
 	}
 
-	// TODO KAI TIDY INTO FUNCTION
+	// TODO TIDY INTO FUNCTION
 
 	log.Printf("[INFO] Identify connections to delete")
 	// connections to delete - any connection which is in connection state but NOT required connections
